"use strict";

/**
 * 解决事件监听 this 问题，这里 转接一下
 */
export class MyEventListener {

    constructor(styleClass) {
        //这里监听鼠标按下事件
        document.getElementById("_style_utils").addEventListener("mousedown", function (e) {
            const event = window.myEdit.utils.ParseEvent(e);
            window.myEdit.utils.ProhibitDefaultEvent(event);
        },true)

        //样式事件
        let styleList = document.getElementsByClassName(styleClass);
        // console.log(styleList);
        if (styleList && styleList.length > 0) {
            for (let i = 0; i < styleList.length; i++) {
                // console.log(styleList[i]);
                styleList[i].addEventListener('click', this.SurroundContentsByStyleListener, true);
            }
        }
    }

    SurroundContentsByStyleListener(e) {
        const event = window.myEdit.utils.ParseEvent(e);
        console.log("SurroundContentsByStyleListener : ", e, event);
        //业务
        window.myEdit.biz.surroundContentsByStyleHandler(event);
    }

    /**
     * 鼠标按下事件 & 键盘组合事件
     * @param {*} e
     */
    KeydownListener(e) {
        const event = window.myEdit.utils.ParseEvent(e);
        // console.log("this: ", this, e, e.target, "\n event: ", event)


        const keyCode = window.myEdit.utils.GetKeyCode(event);
        const keyCombination = event.ctrlKey
        const metaKey = event.metaKey
        // console.log("键盘事件 ", event, keyCombination, metaKey, keyCode)

        // ctrl + c 复制
        if (keyCombination && keyCode === 67) {
            // 阻止默认事件
            window.myEdit.utils.ProhibitDefaultEvent(event);
            console.log('触发ctrl + c 事件', e.target)
        }

        //撤销
        if (metaKey && keyCode === 90) {
            window.myEdit.biz.cancelHandle(event)
            return;
        }

        //删除
        if (keyCode === 46 || keyCode === 8) {
            window.myEdit.biz.deleteHandle(event);
            return;
        }

        //回车事件
        if (keyCode === 13 /* && currentNode === key.lastElementChild */) {
            window.myEdit.biz.enterHandler(event);
            return;
        }

        //空格键
        if (keyCode === 32) {
            console.log('触发 空格 事件', e.target)
            window.myEdit.biz.emptyKeyWorkHandler(event);
            return;
        }
    }

    /**
     * 窗口撤销事件
     * @param e
     * @constructor
     */
    WindowsCtrZHandle(e) {
        const event = window.myEdit.utils.ParseEvent(e);
        const keyCode = window.myEdit.utils.GetKeyCode(event);
        const metaKey = event.metaKey;
        if (metaKey && keyCode === 90) {
            window.myEdit.biz.cancelHandle(event);
        }
    }

    /**
     * 输入事件
     * @param e
     * @constructor
     */
    InputListener(e) {
        const event = window.myEdit.utils.ParseEvent(e);
        console.log("input : ",event)
        window.myEdit.biz.inputHandle(event);
    }

    /**
     * 中文输入开始事件
     * @param e
     * @constructor
     */
    CompositionstartListener(e) {
        const event = window.myEdit.utils.ParseEvent(e);
        window.myEdit.biz.compositionstartHandle(event);
    }

    /**
     * 中文输入结束事件
     * @param e
     * @constructor
     */
    CompositionendListener(e) {
        const event = window.myEdit.utils.ParseEvent(e);
        console.log("Compositionend : ",event)
        window.myEdit.biz.compositionendHandle(event);
    }

    /**
     * 注册事件处理器
     * @param eventName
     * @param handler
     */
    RegisterEventHandle(eventName, handler) {
        window.myEdit.ctx.MyRoot.addEventListener(eventName, handler);
    }

    /**
     * 监听鼠标抬起事件
     * @param e
     * @constructor
     */
    MouseUp(e) {
        let styleUtils = document.getElementById("_style_utils");
        if (window.myEdit.utils.GetSelection().isCollapsed) {
            styleUtils.style.display = "none";
            return
        }

        let posX = 0, posY = 0;
        const event = window.myEdit.utils.ParseEvent(e);
        // if (event.pageX || event.pageY) {
        //     posX = event.pageX;
        //     posY = event.pageY;
        // } else if (event.clientX || event.clientY) {
        //     posX = event.clientX + document.body.scrollLeft + document.documentElement.scrollLeft;
        //     posY = event.clientY + document.body.scrollTop + document.documentElement.scrollTop;
        // }

        var scrollX = document.documentElement.scrollLeft || document.body.scrollLeft;
        var scrollY = document.documentElement.scrollTop || document.body.scrollTop;
        var x = event.pageX || event.clientX + scrollX;
        var y = event.pageY || event.clientY + scrollY;

        console.log("posX: ", x, " posY: ", y, event.pageX, event.pageY, scrollX, scrollY, event.clientX, event.clientY);

        //
        styleUtils.style.display = "block";
        styleUtils.style.left = (event.clientX - 60) + "px";
        styleUtils.style.top = (event.clientY - 60) + "px";

        // window.myEdit.utils.ProhibitDefaultEvent(event);
    }
}

